#
# $Id: Constants.pl,v 36.1 2010/08/02 20:36:04 anbrown Exp $
#
# (c) 1999-2010 Morgan Stanley & Co. Incorporated
# See ..../src/LICENSE for terms of distribution.
#

package MQSeries::Constants;

require "MQSeries/Constants/AttributeLength.pl";
require "MQSeries/Constants/AttributeString.pl";
require "MQSeries/Constants/ReasonMacro.pl";
require "MQSeries/Constants/ReasonQualifierMacro.pl";
require "MQSeries/Constants/ReasonQualifierText.pl";
require "MQSeries/Constants/ReasonText.pl";
require "MQSeries/Constants/StringAttribute.pl";
require "MQSeries/Constants/ValidPutMsgRecFields.pl";

1;
